import { DataTypes, Model, Optional, Sequelize } from "sequelize";


interface WorkerAttributes {
  id:number;
  email: string;
  first_name: string;
  last_name: string;
  password: string;
  role: string;
}
export interface WorkerOutput extends Required<WorkerAttributes> {}
export interface WorkerInput extends Optional<WorkerAttributes, "id"> {}
class Worker extends Model<WorkerAttributes> implements WorkerAttributes {
  declare id:number;
  declare email: string;
  declare first_name: string;
  declare last_name: string;
  declare password: string;
  declare role: string; 
  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}
export const initWorker = async (sequelizeConnection: Sequelize) => {
  Worker.init(
    {
      id: {
        type: DataTypes.INTEGER.UNSIGNED,
        autoIncrement: true,
        primaryKey: true,
      },
      email: {
        type: new DataTypes.STRING(),
        allowNull: false,
        unique: true,
      },
      first_name: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      last_name: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      password: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
      role: {
        type: new DataTypes.STRING(),
        allowNull: false,
      },
    },
    {
      tableName: "worker",
      sequelize: sequelizeConnection,
    }
  );
};
/*
--------------------------all those wrapper-functions are not needed. Query-functions can be calles simply using Model---------------------------------------------------------


export const create = async (payload: Worker): Promise<WorkerOutput> => {
  return await Worker.create(payload);
};

export const update = async (
  email: string,
  payload: Partial<WorkerInput>
): Promise<WorkerOutput> => {
  const worker = await Worker.findByPk(email);
  if (!worker) {
    throw new Error("not found");
  }
  return await (worker as Worker).update(payload);
};

export const getById = async (email: string): Promise<WorkerInput> => {
  const worker = await Worker.findByPk(email);
  if (!worker) {
    throw new Error("not found");
  }
  return worker;
};

const deleteById = async (email: string): Promise<boolean> => {
  const deletedWorkerCount = await Worker.destroy({
    where: { email },
  });
  return !!deletedWorkerCount;
};
export const getAll = async (): Promise<WorkerOutput[]> => {
  return Worker.findAll();
};
export const WorkerService = {
  create,
  update,
  getById,
  deleteById,
  getAll,
};
*/
export default Worker;
