import cookieParser from "cookie-parser";
import "dotenv/config";
import express from "express";
import initializeDatabase from "./db";
import createInitialWorkerIfNotExists from "./db/createInitialWorker";
import showAllDBs from "./db/DB_Information/showAllDBs";
import showTables from "./db/DB_Information/showDBTables";
import showTableContent from "./db/DB_Information/showTableContent";
import runSeeders from "./db/seeder";
import accountsRouter from "./routes/accounts.routes";
import authRouter from "./routes/auth.routes";
import boatsRouter from "./routes/boatRoutes.routes";
import userRouter from "./routes/user.routes";

let init = async () => {
  //DB
  const sequelize = await initializeDatabase();
  await createInitialWorkerIfNotExists();
  await runSeeders();
  // server
  const app = express();
  app.use(express.json());
  app.use(cookieParser());
  const port = process.env.PORT || 4000;
  app.listen(port, () => console.log(`Server listening on port: ${port}\n`));
  app.get("/", (req, res) => res.send("hello in server"));
  app.use("/", authRouter);
  app.use("/", accountsRouter);
  app.use("/", boatsRouter);
  app.use("/", userRouter);
  //DB-information section
  await showAllDBs(sequelize);
  await showTables(sequelize);
  await showTableContent("worker", sequelize);
};

init().then(() => {});
